Module respack

Module respack 

Resource pack for build.rs

Functions

pack
Pack a folder as a resources Assumed to be called at build.rs, i.e. build time only Generates a source file “generated.rs” that can be included in the application sources and be loaded as a filemap for a dynamic access.